@@ -39,6 +39,9 @@ from mitosheet.sheet_functions import *
 # And the functions for changing types
 from mitosheet.sheet_functions.types import *
 
+# Export the graph filtering code, so that it can be used in the code that generates graphs
+from mitosheet.api.graph.graph_utils import filter_df_to_safe_size
+
 # Make sure the user is initalized
 initialize_user()
 log('imported_mitosheet', check_mitosheet_install=True)
