@@ -345,20 +345,6 @@ def make_is_directory_error(file_name):
     )
 
 
-def make_duplicated_pivot_column_error(column_header):
-    """
-    Helper function for creating duplicated_pivot_column_error
-
-    Occurs when:
-    - the user adds a column to both the row and the value section of the pivot table
-        which is not covered by a special case
-    """
-    return EditError(
-        'duplicated_column_in_pivot_error',
-        f'Invalid Pivot Configuration',
-        f'Sorry, the column {column_header} is used twice. Please remove it from one section.'
-    )
-
 ARG_FULL_NAME = {
     'int': 'number',
     'float': 'number',
