@@ -41,7 +41,7 @@ STEP_PERFORMERS: List[StepPerformer] = [
     SimpleImportStepPerformer,
     DataframeDeleteStepPerformer,
     DataframeDuplicateStepPerformer,
-    DataframeRenameStepPerformer
+    DataframeRenameStepPerformer,
 ]
 
 # A helpful mapping for looking up steps based on the incoming events
